@@ -24,7 +24,7 @@ except ImportError:
         return dt.datetime.strptime(string, '%Y-%m-%d %H:%M:%S.%f')
 
 
-__all__ = ["what_py_converter", "rows2ch", "json2ch", "py2ch"]
+__all__ = ["what_py_converter", "rows2ch", "json2ch", "py2ch", "empty_convertor"]
 
 
 RE_TUPLE = re.compile(r"^Tuple\((.*)\)$")
@@ -62,7 +62,7 @@ class BaseType(ABC):
 
     @abstractmethod
     def p_type(self, string):
-        """ Function for implementing specific actions for each type """
+        """Function for implementing specific actions for each type"""
 
     @classmethod
     def decode(cls, val: bytes) -> str:
@@ -385,16 +385,22 @@ PY_TYPES_MAPPING = {
 
 
 def what_py_type(name: str, container: bool = False) -> BaseType:
-    """ Returns needed type class from clickhouse type name """
+    """Returns needed type class from clickhouse type name"""
     name = name.strip()
     try:
-        return CH_TYPES_MAPPING[name.split("(")[0]](name, container=container)
+        if name.startswith('SimpleAggregateFunction') or name.startswith(
+            'AggregateFunction'
+        ):
+            ch_type = re.findall(r',(.*)\)', name)[0].strip()
+        else:
+            ch_type = name.split("(")[0]
+        return CH_TYPES_MAPPING[ch_type](name, container=container)
     except KeyError:
         raise ChClientError(f"Unrecognized type name: '{name}'")
 
 
 def what_py_converter(name: str, container: bool = False) -> Callable:
-    """ Returns needed type class from clickhouse type name """
+    """Returns needed type class from clickhouse type name"""
     return what_py_type(name, container).convert
 
 
@@ -416,3 +422,7 @@ def rows2ch(*rows):
 
 def json2ch(*records, dumps: Callable[[Any], bytes]):
     return dumps(records)[1:-1]
+
+
+def empty_convertor(value: bytes) -> bytes:
+    return value
